# EndDatePolicy

End date policy of the discount charge to become active when the **Apply to billing period partially** checkbox is selected from the product catalog UI or the `applyToBillingPeriodPartially` field is set as true from the \"CRUD: Create a product rate plan charge\" operation.  

## Enum

* `ALIGNTOAPPLYTOCHARGE` (value: `'AlignToApplyToCharge'`)

* `SPECIFICENDDATE` (value: `'SpecificEndDate'`)

* `FIXEDPERIOD` (value: `'FixedPeriod'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


